# IBATS_Utils
IBATS 通用工具，该工具涉及数据库、量化、以及一些通用工具。

#### 版本历史

* 2021-09-12 \[1.20210912.0]
  > feat: add no_with_if_is_none.

* 2021-08-20 \[1.20210820.0]
  > isinstance(obj, np.bool_)

* 2021-06-28 \[1.20210628.0]
  > fix: @njit on least_common_multiple_arr, least_common_multiple.

* 2021-06-23 \[1.20210623.0]
  > feat: add math module.\
  > feat: add get_file_name_iter.\
  > refactor: split mess funcs to separated modules.

* 2021-06-18 \[1.20210618.0]
  > fix: cls=SimpleJsonEncoder.

* 2021-06-07 \[1.20210607.1]
  > feat: enhance dict_2_jsonable, obj_2_json.\
  > fix: JsonEncoder, SimpleJsonEncoder on Enum value.\
  > feat: use CalVer

#### 编译命令
```bash
python setup.py build bdist_wheel
twine upload dist/*
```
